@@ -1,6 +1,6 @@
 package CPAN::InGit;
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 # ABSTRACT: Manage custom CPAN trees to pin versions for your projects
 
 use Git::Raw::Repository;
@@ -133,7 +133,7 @@ sub lookup_tree($self, $branch_or_tag_or_id) {
 sub add_git_tree_to_tar($self, $tar, $path, $tree) {
    unless ($tree->can('entries')) {
       my $id= $tree;
-      $tree = Git::Raw::Tree->lookup($self->repo, $id)
+      $tree = Git::Raw::Tree->lookup($self->git_repo, $id)
          or die "Can't find TREE $id referenced by '$path'";
    }
    $self->add_git_dirent_to_tar($tar, "$path/".$_->name, $_)
@@ -143,7 +143,7 @@ sub add_git_tree_to_tar($self, $tar, $path, $tree) {
 sub add_git_dirent_to_tar($self, $tar, $path, $dirent) {
    if ($dirent->type == Git::Raw::Object::BLOB()) {
       my $mode = $dirent->file_mode;
-      my $blob = Git::Raw::Blob->lookup($self->repo, $dirent->id)
+      my $blob = Git::Raw::Blob->lookup($self->git_repo, $dirent->id)
          or die "Can't find BLOB ".$dirent->id." referenced by '$path'";
       # Check if it's a symlink (mode 0120000 or 40960 decimal)
       if (($mode & 0170000) == 0120000) {
@@ -470,7 +470,7 @@ L</upstream_mirrors>.
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
